---
name: Feature request
about: Suggest an idea for this project
title: '[FEATURE] '
labels: enhancement
assignees: ''
---

## Is your feature request related to a problem? Please describe.
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

## Describe the solution you'd like
A clear and concise description of what you want to happen. Include any API design ideas or features you would like to see.

## Describe alternatives you've considered
A clear and concise description of any alternative solutions or features you've considered.

## Use case
Explain how this feature would be used and who would use it.

## Additional context
Add any other context or screenshots about the feature request here.